@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
 from coop_cms.settings import get_article_class
-from coop_cms.utils import get_article
+from coop_cms.shortcuts import get_article
 from django import template
 register = template.Library()
-from django.template.defaultfilters import slugify
+from django.utils.text import slugify
 from coop_cms.utils import dehtml as do_dehtml
 from bs4 import BeautifulSoup
 import unicodedata
 from django.conf import settings
-    
+from floppyforms import CheckboxInput
+from coop_cms.models import ArticleCategory
+import os.path
+
 ################################################################################
 class ArticleLinkNode(template.Node):
 
@@ -105,4 +108,52 @@ def normalize_utf8_to_ascii(ustr):
         return unicodedata.normalize('NFKD', ustr).encode('ascii','ignore')
     except TypeError:
         return ustr
-    
\ No newline at end of file
+    
+
+@register.filter(name='is_checkbox')
+def is_checkbox(field):
+    field = getattr(field, 'field', field) # get the field attribute of the field or the field itself
+    return field.widget.__class__.__name__ == CheckboxInput().__class__.__name__
+    
+@register.filter
+def index(seq, index):
+    try:
+        return seq[index]
+    except IndexError:
+        return None
+
+################################################################################
+class CoopCategoryNode(template.Node):
+
+    def __init__(self, cat_slug, var_name):
+        cat = cat_slug.strip("'").strip('"')
+        self.cat_var, self.cat = None, None
+        if cat_slug == cat:
+            self.cat_var = template.Variable(cat)
+        else:
+            self.cat = cat
+        self.var_name = var_name
+
+    def render(self, context):
+        if self.cat_var:
+            self.cat = self.cat_var.resolve(context)
+        try:
+            slug = slugify(self.cat)
+            self.category = ArticleCategory.objects.get(slug=slug)
+        except ArticleCategory.DoesNotExist:
+            self.category = ArticleCategory.objects.create(name=self.cat)
+        context.dicts[0][self.var_name] = self.category
+        return ""
+
+@register.tag
+def coop_category(parser, token):
+    #Newsletter friendly CSS
+    args = token.split_contents()
+    cat_slug = args[1]
+    var_name = args[2]
+    return CoopCategoryNode(cat_slug, var_name)
+
+
+@register.filter
+def basename(fullname):
+    return os.path.basename(fullname)
