@@ -2,7 +2,7 @@
 
 from django.http import HttpResponse, Http404, HttpResponseRedirect, HttpResponseForbidden
 from django.shortcuts import render_to_response, get_object_or_404
-from django.template import RequestContext, Context, Template
+from django.template import RequestContext, Context, Template, TemplateDoesNotExist
 from django.template.loader import get_template
 from django.core.urlresolvers import reverse
 import sys, json, os.path
@@ -17,19 +17,22 @@ from django.contrib.messages.api import error as error_message
 from coop_cms import models
 from django.contrib.auth.decorators import login_required
 from coop_cms.settings import get_article_class, get_article_form, get_newsletter_form, get_navtree_class
+from coop_cms.settings import get_new_article_form, get_article_settings_form
 from djaloha import utils as djaloha_utils
 from django.core.servers.basehttp import FileWrapper
 import mimetypes, unicodedata
 from django.conf import settings
 from django.contrib import messages
-from colorbox.decorators import popup_redirect
-from coop_cms.utils import send_newsletter, get_article_or_404, get_headlines, redirect_if_alias
+from colorbox.decorators import popup_redirect, popup_close
+from coop_cms.utils import send_newsletter
+from coop_cms.shortcuts import get_article_or_404, get_headlines, redirect_if_alias
 from django.utils.log import getLogger
 from datetime import datetime
 from django.utils.translation import check_for_language, activate, get_language
 from urlparse import urlparse
 from django.contrib.sites.models import Site
 from generic_views import EditableObjectView
+from django.forms.models import modelformset_factory
 import logging
 logger = logging.getLogger("coop_cms")
 
@@ -272,7 +275,7 @@ def show_media(request, media_type):
                 'html': html,
                 'media_type': media_type,
             }
-            return HttpResponse(json.dumps(data), mimetype="application/json")
+            return HttpResponse(json.dumps(data), content_type="application/json")
         else:
             return HttpResponse(html)
     except Exception:
@@ -355,14 +358,19 @@ def change_template(request, article_id):
 @popup_redirect
 def article_settings(request, article_id):
     article = get_object_or_404(get_article_class(), id=article_id)
+    ArticleSettingsForm = get_article_settings_form()
+    
+    if not request.user.has_perm('can_edit_article', article):
+        raise PermissionDenied
+    
     if request.method == "POST":
-        form = forms.ArticleSettingsForm(request.user, request.POST, request.FILES, instance=article)
+        form = ArticleSettingsForm(request.user, request.POST, request.FILES, instance=article)
         if form.is_valid():
             #article.template = form.cleaned_data['template']
             article = form.save()
             return HttpResponseRedirect(article.get_absolute_url())
     else:
-        form = forms.ArticleSettingsForm(request.user, instance=article)
+        form = ArticleSettingsForm(request.user, instance=article)
 
     context = {
         'article': article,
@@ -378,6 +386,8 @@ def article_settings(request, article_id):
 @popup_redirect
 def new_article(request):
     Article = get_article_class()
+    NewArticleForm = get_new_article_form()
+    
     ct = ContentType.objects.get_for_model(Article)
     perm = '{0}.add_{1}'.format(ct.app_label, ct.model)
 
@@ -385,14 +395,14 @@ def new_article(request):
         raise PermissionDenied
 
     if request.method == "POST":
-        form = forms.NewArticleForm(request.user, request.POST, request.FILES)
+        form = NewArticleForm(request.user, request.POST, request.FILES)
         if form.is_valid():
             #article.template = form.cleaned_data['template']
             article = form.save()
             success_message(request, _(u'The article has been created properly'))
             return HttpResponseRedirect(article.get_edit_url())
     else:
-        form = forms.NewArticleForm(request.user)
+        form = NewArticleForm(request.user)
 
     return render_to_response(
         'coop_cms/popup_new_article.html',
@@ -471,12 +481,12 @@ def update_logo(request, article_id):
                 article.save()
                 url = article.logo_thumbnail(True).url
                 data = {'ok': True, 'src': url}
-                return HttpResponse(json.dumps(data), mimetype='application/json')
+                return HttpResponse(json.dumps(data), content_type='application/json')
             else:
                 t = get_template('coop_cms/popup_update_logo.html')
                 html = t.render(Context(locals()))
                 data = {'ok': False, 'html': html}
-                return HttpResponse(json.dumps(data), mimetype='application/json')
+                return HttpResponse(json.dumps(data), content_type='application/json')
         else:
             form = forms.ArticleLogoForm()
     
@@ -508,7 +518,7 @@ def download_doc(request, doc_id):
         mime_type = mimetypes.guess_type(file.name)[0]
         if not mime_type:
             mime_type = u'application/octet-stream'
-        response = HttpResponse(wrapper, mimetype=mime_type)
+        response = HttpResponse(wrapper, content_type=mime_type)
         response['Content-Length'] = file.size
         filename = unicodedata.normalize('NFKD', os.path.split(file.name)[1]).encode("utf8", 'ignore')
         filename = filename.replace(' ', '-')
@@ -828,7 +838,7 @@ def process_nav_edition(request, tree_id):
         #     response = {'status': 'error', 'message': u"An error occured"}
 
         #return the result as json object
-        return HttpResponse(json.dumps(response), mimetype='application/json')
+        return HttpResponse(json.dumps(response), content_type='application/json')
     raise Http404
 
 
@@ -965,12 +975,84 @@ def schedule_newsletter_sending(request, newsletter_id):
         context_instance=RequestContext(request)
     )
 
+@login_required
+@popup_close
+def add_fragment(request):
+    """add a fragment to the current template"""
+    
+    ct = ContentType.objects.get_for_model(models.Fragment)
+    perm = '{0}.add_{1}'.format(ct.app_label, ct.model)
+    if not request.user.has_perm(perm):
+        raise PermissionDenied
+
+    if request.method == "POST":
+        form = forms.AddFragmentForm(request.POST)
+        if form.is_valid():
+            form.save()
+            return None #popup_close decorator will close and refresh
+    else:
+        form = forms.AddFragmentForm()
+        
+    context_dict = {
+        'form': form,
+    }
+
+    return render_to_response(
+        'coop_cms/popup_add_fragment.html',
+        context_dict,
+        context_instance=RequestContext(request)
+    )
+
+@login_required
+@popup_close
+def edit_fragments(request):
+    """edit fragments of the current template"""
+    
+    ct = ContentType.objects.get_for_model(models.Fragment)
+    perm = '{0}.add_{1}'.format(ct.app_label, ct.model)
+    if not request.user.has_perm(perm):
+        raise PermissionDenied
+    
+    EditFragmentFormset = modelformset_factory(models.Fragment, forms.EditFragmentForm, extra=0)
+
+    if request.method == "POST":
+        formset = EditFragmentFormset(request.POST, queryset=models.Fragment.objects.all())
+        if formset.is_valid():
+            formset.save()
+            return None #popup_close decorator will close and refresh
+    else:
+        formset = EditFragmentFormset(queryset=models.Fragment.objects.all())
+    
+    context_dict = {
+        'form': formset,
+        'title': _(u"Edit fragments of this template?"),
+    }
+
+    return render_to_response(
+        'coop_cms/popup_edit_fragments.html',
+        context_dict,
+        context_instance=RequestContext(request)
+    )
 
 def articles_category(request, slug):
     category = get_object_or_404(models.ArticleCategory, slug=slug)
-    articles = get_article_class().objects.filter(category=category).order_by("-created")
+    
+    if not request.user.has_perm('can_view_category', category):
+        raise PermissionDenied()
+    
+    articles = get_article_class().objects.filter(category=category, publication=models.BaseArticle.PUBLISHED).order_by("-created")
+    
+    if articles.count()==0:
+        raise Http404
+    
+    try:
+        category_template = u"coop_cms/categories/{0}.html".format(category.slug)
+        get_template(category_template)
+    except TemplateDoesNotExist:
+        category_template = "coop_cms/articles_category.html"
+    
     return render_to_response(
-        'coop_cms/articles_category.html',
+        category_template,
         {'category': category, "articles": articles},
         context_instance=RequestContext(request)
     )
